@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #ifndef GLOM_APPLICATION_H
@@ -38,6 +38,7 @@ public:
 protected:
   //Overrides of default signal handlers:
   virtual void on_activate();
+  virtual void on_startup();
   virtual void on_open(const Gio::Application::type_vec_files& files,
     const Glib::ustring& hint);
   virtual int on_command_line(const Glib::RefPtr<Gio::ApplicationCommandLine>& command_line);
