@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include "entry.h"
@@ -42,20 +42,12 @@ Entry::Entry(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& /* build
   Gtk::Entry(cobject),
   m_glom_type(Field::TYPE_TEXT)
 {
-#ifndef GLOM_ENABLE_CLIENT_ONLY
-  setup_menu();
-#endif // !GLOM_ENABLE_CLIENT_ONLY
   init();
 }
 
 Entry::Entry(Field::glom_field_type glom_type)
-:
-  m_glom_type(glom_type)
+: m_glom_type(glom_type)
 {
-#ifndef GLOM_ENABLE_CLIENT_ONLY
-  setup_menu();
-#endif // !GLOM_ENABLE_CLIENT_ONLY
-
   init();
 }
 
@@ -65,6 +57,9 @@ Entry::~Entry()
 
 void Entry::init()
 {
+#ifndef GLOM_ENABLE_CLIENT_ONLY
+  setup_menu(this);
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 }
 
 void Entry::set_layout_item(const sharedptr<LayoutItem>& layout_item, const Glib::ustring& table_name)
@@ -82,8 +77,8 @@ void Entry::set_layout_item(const sharedptr<LayoutItem>& layout_item, const Glib
   if(layout_field)
     alignment = layout_field->get_formatting_used_horizontal_alignment(true /* for details view */);
 
-  const float x_align = (alignment == Formatting::HORIZONTAL_ALIGNMENT_LEFT ? 0.0 : 1.0);
-  set_alignment(x_align);
+  const Gtk::Align x_align = (alignment == Formatting::HORIZONTAL_ALIGNMENT_LEFT ? Gtk::ALIGN_START : Gtk::ALIGN_END);
+  set_halign(x_align);
 }
 
 void Entry::set_glom_type(Field::glom_field_type glom_type)
