@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 
@@ -66,7 +66,7 @@ Glib::ustring Dialog_FlowTable::get_title()
   return m_entry_title->get_text();
 }
 
-gint Dialog_FlowTable::get_columns_count()
+gint Dialog_FlowTable::get_columns_count() const
 {
   return m_spin_columns->get_value_as_int();
 }
