@@ -75,7 +75,8 @@ void FileChooserDialog_SaveExtras::set_extra_message(const Glib::ustring& messag
 void FileChooserDialog_SaveExtras::create_child_widgets()
 {
   //m_extra_widget.pack_start(m_label_extra_message);
-  m_label_extra_message.set_alignment(0.0f, 0.5f);
+  m_label_extra_message.set_halign(Gtk::ALIGN_START);
+  m_label_extra_message.set_valign(Gtk::ALIGN_CENTER);
 
   Gtk::Frame* frame = Gtk::manage(new Gtk::Frame());
   Gtk::Label* frame_label = Gtk::manage(new Gtk::Label());
@@ -83,22 +84,20 @@ void FileChooserDialog_SaveExtras::create_child_widgets()
   frame_label->show();
   frame->set_label_widget(*frame_label);
   frame->set_shadow_type(Gtk::SHADOW_NONE);
-
-  Gtk::Alignment* alignment = Gtk::manage(new Gtk::Alignment());
-  alignment->set_padding(UiUtils::DEFAULT_SPACING_SMALL, 0, UiUtils::DEFAULT_SPACING_LARGE, 0); //Add padding at the top and left.
-  alignment->show();
-  frame->add(*alignment);
   frame->show();
 
   Gtk::Box* vbox = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL, UiUtils::DEFAULT_SPACING_SMALL));
-  alignment->add(*vbox);
+  vbox->set_margin_start(UiUtils::DEFAULT_SPACING_LARGE);
+  vbox->set_margin_top(UiUtils::DEFAULT_SPACING_SMALL);
+  frame->add(*vbox);
   vbox->show();
 
   vbox->pack_start(m_label_extra_message); /* For instance, an extra hint when saving from an example, saying that a new file must be saved. */
 
   Gtk::Label* label_newdb = Gtk::manage(new Gtk::Label(_("Please choose a human-readable title for the new database. You can change this later in the database properties. It may contain any characters.")));
   vbox->pack_start(*label_newdb);
-  label_newdb->set_alignment(0.0f, 0.5f);
+  label_newdb->set_halign(Gtk::ALIGN_START);
+  label_newdb->set_valign(Gtk::ALIGN_CENTER);
   label_newdb->show();
 
   Gtk::Box* box_label = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL, UiUtils::DEFAULT_SPACING_LARGE));
