@@ -23,6 +23,7 @@
 #include <glom/appwindow.h>
 #include <glom/mode_data/datawidget/textview.h>
 #include <glom/mode_data/datawidget/label.h>
+#include <iostream>
 
 namespace Glom
 {
@@ -103,16 +104,20 @@ void LayoutWidgetBase::apply_formatting(Gtk::Widget& widget, const sharedptr<con
       widget_to_change = labelglom->get_label();
   }
 
+  if(!widget_to_change)
+  {
+    std::cerr << G_STRFUNC << ": widget_to_change is null." << std::endl;
+    return;
+  }
+
   if(!layout_item)
     return;
 
   //Horizontal alignment:
   const Formatting::HorizontalAlignment alignment =
     layout_item->get_formatting_used_horizontal_alignment(true /* for details view */);
-  const float x_align = (alignment == Formatting::HORIZONTAL_ALIGNMENT_LEFT ? 0.0 : 1.0);
-  Gtk::Misc* misc = dynamic_cast<Gtk::Misc*>(widget_to_change);
-  if(misc)
-    misc->set_alignment(x_align);
+  const Gtk::Align x_align = (alignment == Formatting::HORIZONTAL_ALIGNMENT_LEFT ? Gtk::ALIGN_START : Gtk::ALIGN_END);
+  widget_to_change->set_halign(x_align);
     
   //Set justification on labels:
   //Assume that people want left/right justification of multi-line text if they chose 
